@@ -9,7 +9,7 @@ use Digest::SHA();
 use WebService::HIBP::Breach();
 use WebService::HIBP::Paste();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub _LENGTH_OF_PASSWORD_PREFIX { return 5; }
 
@@ -154,7 +154,7 @@ WebService::HIBP - An interface to the Have I Been Pwned webservice at haveibeen
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 SYNOPSIS
 
@@ -185,15 +185,13 @@ a new C<WebService::HIBP> object, ready to check how bad the pwnage is.
 
 =head2 password
 
-The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> has more than half a billion passwords which have previously been exposed in data breaches. The service is detailed in the L<launch blog post|https://www.troyhunt.com/introducing-306-million-freely-downloadable-pwned-passwords/> then L<further expanded on with the release of version 2|https://www.troyhunt.com/ive-just-launched-pwned-passwords-version-2>. The entire data set is L<both downloadable and searchable online via the Pwned Passwords page|https://haveibeenpwned.com/Passwords>.
+The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> has more than half a billion passwords which have previously been exposed in data breaches. The service is detailed in the L<launch blog post|https://www.troyhunt.com/introducing-306-million-freely-downloadable-pwned-passwords/> then L<further expanded on with the release of version 2|https://www.troyhunt.com/ive-just-launched-pwned-passwords-version-2>. 
 
-Each password is stored as a SHA-1 hash of a UTF-8 encoded password. The downloadable source data delimits the full SHA-1 hash and the password count with a colon (:) and each line with a CRLF.
+In order to protect the value of the source password being searched for, this method implements a L<k-Anonymity|https://en.wikipedia.org/wiki/K-anonymity> model that searches for a password by partial hash. This method sends the first 5 characters of a SHA-1 password hash (the prefix) to be passed to the L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords>.
 
-In order to protect the value of the source password being searched for, this method implements a k-Anonymity model that searches for a password by partial hash. This method sends the first 5 characters of a SHA-1 password hash to be passed to the L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords>.
+The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> will respond with a list of the suffix of every hash beginning with the specified prefix, followed by a count of how many times it appears in the data set. This method then searches the results of the response for the presence of their source hash. If not found, the password does not exist in the data set.  
 
-The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> will respond with a list of the suffix of every hash beginning with the specified prefix, followed by a count of how many times it appears in the data set. This method then searches the results of the response for the presence of their source hash and if not found, the password does not exist in the data set.  
-
-It returns the count of how many times it appears in the data set or "0" if it dosen't appear.
+This method then returns the count of how many times it appears in the data set or "0" if it dosen't appear.
 
     use WebService::HIBP();
     use IO::Prompt();
@@ -229,8 +227,8 @@ Parameters:
 
     my $hibp = WebService::HIBP->new();
     foreach my $breach ( $hibp->account( 'test@example.com', domain => 'adobe.com' ) ) {
-	   say $breach->name();
-	}
+        say $breach->name();
+    }
 
 =head2 breach
 
@@ -261,8 +259,8 @@ Parameters:
 
     my $hibp = WebService::HIBP->new();
     foreach my $breach ( $hibp->breaches( domain => 'adobe.com' ) ) {
-	   say $breach->name();
-	}
+        say $breach->name();
+    }
 
 =head2 data_classes
 
@@ -273,8 +271,8 @@ A "data class" is an attribute of a record compromised in a breach. For example,
 
     my $hibp = WebService::HIBP->new();
     foreach my $class ( $hibp->data_classes() ) {
-	   say $class;
-	}
+        say $class;
+    }
 
 =head2 pastes
 
@@ -285,8 +283,8 @@ This method takes a single parameter which is the email address to be searched f
 
     my $hibp = WebService::HIBP->new();
     foreach my $paste ( $hibp->pastes( 'test@example.com' ) ) {
-	   say $paste->source();
-	}
+        say $paste->source();
+    }
 
 =head1 DIAGNOSTICS
 
@@ -308,6 +306,7 @@ WebService::HIBP requires the following non-core modules
 
   JSON
   LWP::UserAgent
+  LWP::Protocol::https
   URI::Escape
   Digest::SHA
 
